/*  -- translated by f2c (version 20160102).
   You must link the resulting object file with libf2c:
	on Microsoft Windows system, link with libf2c.lib;
	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
	or, if you install libf2c.a in a standard place, with -lf2c -lm
	-- in that order, at the end of the command line, as in
		cc *.o -lf2c -lm
	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,

		http://www.netlib.org/f2c/libf2c.zip
*/

#include "libtinyf2c.h"

/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
logical lreq1_(real *x, real *y)
{
    /* Initialized data */

    static logical lfrst = TRUE_;

    /* System generated locals */
    real r__1;
    logical ret_val;

    /* Local variables */
    static real ep, rfact, repsl;
    extern /* Subroutine */ int glrget_(char *, real *, ftnlen);

    if (lfrst) {
	glrget_("REPSL", &repsl, (ftnlen)5);
	lfrst = FALSE_;
    }
    glrget_("RFACT", &rfact, (ftnlen)5);
    ep = repsl * rfact;
    ret_val = (r__1 = *x - *y, abs(r__1)) <= (abs(*x) + abs(*y)) * ep / 2;
    return ret_val;
} /* lreq1_ */

